Verbosity level for functions in connector. See zephyr::verbosity_level for details.
Default: "verbose"
Option: connector.verbosity_level
Environment: R_CONNECTOR_VERBOSITY_LEVEL
Overwrite existing content if it exists in the connector?
See connector-options for details. Default can be set globally with
options(connector.overwrite = TRUE/FALSE) or environment variable
R_CONNECTOR_OVERWRITE.
Default: FALSE
Option: connector.overwrite
Environment: R_CONNECTOR_OVERWRITE
Add logging capability to connectors using add_logs().
When TRUE, all connector operations will be logged to the console and
to whirl log HTML files. See log-functions for available
logging functions.
Default: FALSE
Option: connector.logging
Environment: R_CONNECTOR_LOGGING
Default extension to use when reading and writing files when not specified in the file name. E.g. with the default 'csv', files are assumed to be in CSV format if not specified.
Default: "csv"
Option: connector.default_ext
Environment: R_CONNECTOR_DEFAULT_EXT