Internal parameters for reuse in functions
Verbosity level for functions in connector.
See zephyr::verbosity_level for details.. Default: "verbose".
Overwrite existing content if it exists in the connector?
See connector-options for details. Default can be set globally with
options(connector.overwrite = TRUE/FALSE) or environment variable
R_CONNECTOR_OVERWRITE.. Default: FALSE.
Add logging capability to connectors using add_logs().
When TRUE, all connector operations will be logged to the console and
to whirl log HTML files. See log-functions for available
logging functions.. Default: FALSE.
Default extension to use when reading and writing files when not
specified in the file name. E.g. with the default 'csv', files are assumed
to be in CSV format if not specified.. Default: "csv".
See connector-options for more information.