Internal parameters for reuse in functions
Verbosity level for functions in connector.
See zephyr::verbosity_level for details.. Default: "verbose".
Overwrite existing content if it exists in the connector?. Default: FALSE.
Add logs to the console as well as to the whirl log html files. Default: FALSE.
See connector-options for more information.